@@ -63,7 +63,7 @@ def calculate_growth_rates(time, od, window_size=40):
     return growth_rates, N0s
 
 
-def plot_tube(pe, tube, log_OD=None, log_pumps=None, plot_growth_rate=True,window_size=30):
+def plot_tube(pe, tube, log_OD=None, log_pumps=None, plot_growth_rate=True,window_size=30,close=True):
     if log_OD is None:
         log_OD = pd.read_csv(pe.OD_measurement.od_file, parse_dates=["time"], index_col="time")
     if log_pumps is None:
@@ -136,4 +136,5 @@ def plot_tube(pe, tube, log_OD=None, log_pumps=None, plot_growth_rate=True,windo
     plt.savefig(os.path.join(pe.name, "plot.%d.png" % tube))
     #         plt.xlim(11.6,14)
     plt.show()
-    plt.close()
\ No newline at end of file
+    if close:
+        plt.close()
\ No newline at end of file
